@@ -45,12 +45,10 @@ class XMLCacheManager:
                              end_year=end_year, end_month=end_month, end_day=1, verbose=verbose)
 
     def populate_by_day(self, start_year, start_month, end_year, end_month, start_day, end_day, verbose=True):
-        """Download data to the cache from the AEMO website. Data downloaded is inclusive of the start and end date."""
+        """Download data to the cache from the AEMO website. Data downloaded is inclusive of the start and end date.
+        """
 
         start = datetime(year=start_year, month=start_month, day=start_day) - timedelta(days=1)
-        if end_month == 12:
-            end_month = 0
-            end_year += 1
         end = datetime(year=end_year, month=end_month, day=end_day)
         download_date = start
         while download_date <= end:
@@ -166,7 +164,7 @@ class XMLCacheManager:
             z = zipfile.ZipFile(io.BytesIO(r.content))
             z.extractall(self.cache_folder)
         except zipfile.BadZipFile:
-            sleep(100)
+            sleep(200)
             r = requests.get(url)
             z = zipfile.ZipFile(io.BytesIO(r.content))
             z.extractall(self.cache_folder)
@@ -647,7 +645,7 @@ class XMLCacheManager:
         >>> manager.load_interval('2019/01/01 00:00:00')
 
         >>> manager.get_constraint_violation_prices()
-        {'regional_demand': 2175000.0, 'interocnnector': 16675000.0, 'generic_constraint': 435000.0, 'ramp_rate': 16747500.0, 'unit_capacity': 5365000.0, 'energy_offer': 16457500.0, 'fcas_profile': 2247500.0, 'fcas_max_avail': 2247500.0, 'fcas_enablement_min': 1015000.0, 'fcas_enablement_max': 1015000.0, 'fast_start': 16385000.0, 'mnsp_ramp_rate': 16747500.0, 'msnp_offer': 16457500.0, 'mnsp_capacity': 5292500.0, 'uigf': 5582500.0, 'voll': 14500.0}
+        {'regional_demand': 2175000.0, 'interocnnector': 16675000.0, 'generic_constraint': 435000.0, 'ramp_rate': 16747500.0, 'unit_capacity': 5365000.0, 'energy_offer': 16457500.0, 'fcas_profile': 2247500.0, 'fcas_max_avail': 2247500.0, 'fcas_enablement_min': 1015000.0, 'fcas_enablement_max': 1015000.0, 'fast_start': 16385000.0, 'mnsp_ramp_rate': 16747500.0, 'msnp_offer': 16457500.0, 'mnsp_capacity': 5292500.0, 'uigf': 5582500.0, 'voll': 14500.0, 'tiebreak': 1e-06}
 
         Returns
         -------
@@ -669,7 +667,8 @@ class XMLCacheManager:
                         msnp_offer='@MNSPOfferPrice',
                         mnsp_capacity='@MNSPCapacityPrice',
                         uigf='@UIGFSurplusPrice',
-                        voll='@VoLL')
+                        voll='@VoLL',
+                        tiebreak='@TieBreakPrice')
         violations = {}
         for name, aemo_name in name_map.items():
             violations[name] = float(inputs['Case'][aemo_name])
